@@ -81,6 +81,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_events
@@ -104,11 +106,15 @@ class At(
         :param id: -
         :param date: The future date to use for one time event.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(At.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AtProps(date=date)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="schedule")
     def schedule(self) -> aws_cdk.aws_events.Schedule:
         return typing.cast(aws_cdk.aws_events.Schedule, jsii.get(self, "schedule"))
@@ -124,6 +130,9 @@ class AtProps:
         '''
         :param date: The future date to use for one time event.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AtProps.__init__)
+            check_type(argname="argument date", value=date, expected_type=type_hints["date"])
         self._values: typing.Dict[str, typing.Any] = {
             "date": date,
         }
@@ -164,11 +173,15 @@ class OnDeploy(
         :param id: -
         :param offset_minutes: The number of minutes to add to the current time when generating the expression. Should exceed the expected time for the appropriate resources to converge. Default: 10
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(OnDeploy.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = OnDeployProps(offset_minutes=offset_minutes)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="schedule")
     def schedule(self) -> aws_cdk.aws_events.Schedule:
         return typing.cast(aws_cdk.aws_events.Schedule, jsii.get(self, "schedule"))
@@ -184,6 +197,9 @@ class OnDeployProps:
         '''
         :param offset_minutes: The number of minutes to add to the current time when generating the expression. Should exceed the expected time for the appropriate resources to converge. Default: 10
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(OnDeployProps.__init__)
+            check_type(argname="argument offset_minutes", value=offset_minutes, expected_type=type_hints["offset_minutes"])
         self._values: typing.Dict[str, typing.Any] = {}
         if offset_minutes is not None:
             self._values["offset_minutes"] = offset_minutes
